@@ -42,8 +42,6 @@ import android.widget.AbsListView;
 import android.widget.AdapterView;
 import android.widget.AdapterView.AdapterContextMenuInfo;
 import android.widget.AdapterView.OnItemClickListener;
-import android.widget.ExpandableListView;
-import android.widget.ExpandableListView.ExpandableListContextMenuInfo;
 import android.widget.ImageView;
 import android.widget.ListView;
 import android.widget.PopupMenu;
@@ -88,6 +86,7 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
     private MediaLibrary mMediaLibrary;
     private MediaBrowser mMediaBrowser;
     private MainActivity mMainActivity;
+    private AlertDialog mAlertDialog;
 
     List<MediaWrapper> mAudioList;
     private AudioBrowserListAdapter mArtistsAdapter;
@@ -235,6 +234,9 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             mMediaBrowser.release();
             mMediaBrowser = null;
         }
+
+        if (mAlertDialog != null && mAlertDialog.isShowing())
+            mAlertDialog.dismiss();
     }
 
     @Override
@@ -387,10 +389,8 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
             menu.setGroupVisible(R.id.songs_view_only, false);
             menu.setGroupVisible(R.id.phone_only, false);
         }
-        if (pos == MODE_ARTIST || pos == MODE_GENRE) {
-            MenuItem play = menu.findItem(R.id.audio_list_browser_play);
-            play.setVisible(true);
-        }
+        if (pos == MODE_ARTIST || pos == MODE_GENRE || pos == MODE_ALBUM)
+            menu.findItem(R.id.audio_list_browser_play).setVisible(true);
         if (pos != MODE_SONG && pos != MODE_PLAYLIST)
             menu.findItem(R.id.audio_list_browser_delete).setVisible(false);
         if (!AndroidDevices.isPhone())
@@ -409,10 +409,8 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
     }
 
     private boolean handleContextItemSelected(MenuItem item, int position) {
-        ContextMenuInfo menuInfo = item.getMenuInfo();
 
         int startPosition;
-        int groupPosition;
         int mode = mViewPager.getCurrentItem();
         List<MediaWrapper> medias;
         int id = item.getItemId();
@@ -420,12 +418,6 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
         boolean useAllItems = id == R.id.audio_list_browser_play_all;
         boolean append = id == R.id.audio_list_browser_append;
 
-        if (menuInfo instanceof ExpandableListContextMenuInfo) {
-            ExpandableListContextMenuInfo info = (ExpandableListContextMenuInfo) menuInfo;
-            groupPosition = ExpandableListView.getPackedPositionGroup(info.packedPosition);
-        } else
-            groupPosition = position;
-
         if (id == R.id.audio_list_browser_delete) {
             AudioBrowserListAdapter adapter;
             if (mode == MODE_SONG){
@@ -434,43 +426,66 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 adapter = mPlaylistAdapter;
             } else
                 return false;
-            List<MediaWrapper> mediaList = adapter.getMedias(groupPosition);
-            if (adapter.getCount() <= groupPosition || mediaList == null || mediaList.isEmpty())
+            List<MediaWrapper> mediaList = adapter.getMedias(position);
+            if (adapter.getCount() <= position || mediaList == null || mediaList.isEmpty())
                 return false;
-            AlertDialog alertDialog = CommonDialogs.deletePlaylist(
-                    getActivity(),
-                    adapter.getItem(groupPosition).mTitle,
-                    new VLCRunnable(adapter.getItem(groupPosition)) {
-                        @Override
-                        public void run(Object o) {
-                            AudioBrowserListAdapter.ListItem listItem = (AudioBrowserListAdapter.ListItem) o;
-                            if (!MediaDatabase.getInstance().playlistExists(listItem.mTitle)) {
-                                MediaWrapper media = listItem.mMediaList.get(0);
-                                mMediaLibrary.getMediaItems().remove(media);
-                                if (mAudioController.getMediaLocations().contains(media.getLocation()))
-                                    mAudioController.removeLocation(media.getLocation());
-                            } else {
-                                MediaDatabase.getInstance().playlistDelete(listItem.mTitle);
+            if (mode == MODE_PLAYLIST) {
+                mAlertDialog = CommonDialogs.deletePlaylist(
+                        getActivity(),
+                        adapter.getItem(position).mTitle,
+                        new VLCRunnable(adapter.getItem(position)) {
+                            @Override
+                            public void run(Object o) {
+                                AudioBrowserListAdapter.ListItem listItem = (AudioBrowserListAdapter.ListItem) o;
+                                if (!MediaDatabase.getInstance().playlistExists(listItem.mTitle)) {
+                                    MediaWrapper media = listItem.mMediaList.get(0);
+                                    mMediaLibrary.getMediaItems().remove(media);
+                                    if (mAudioController.getMediaLocations().contains(media.getLocation()))
+                                        mAudioController.removeLocation(media.getLocation());
+                                } else {
+                                    MediaDatabase.getInstance().playlistDelete(listItem.mTitle);
+                                }
+                                updateLists();
                             }
-                            updateLists();
-                        }
-                    });
-            alertDialog.show();
+                        });
+            } else {
+                mAlertDialog = CommonDialogs.deleteMedia(
+                        MediaWrapper.TYPE_ALL,
+                        getActivity(),
+                        adapter.getItem(position).mMediaList.get(0).getLocation(),
+                        adapter.getItem(position).mTitle,
+                        new VLCRunnable(adapter.getItem(position)) {
+                            @Override
+                            public void run(Object o) {
+                                AudioBrowserListAdapter.ListItem listItem = (AudioBrowserListAdapter.ListItem) o;
+                                if (!MediaDatabase.getInstance().playlistExists(listItem.mTitle)) {
+                                    MediaWrapper media = listItem.mMediaList.get(0);
+                                    mMediaLibrary.getMediaItems().remove(media);
+                                    if (mAudioController.getMediaLocations().contains(media.getLocation()))
+                                        mAudioController.removeLocation(media.getLocation());
+                                } else {
+                                    MediaDatabase.getInstance().playlistDelete(listItem.mTitle);
+                                }
+                                updateLists();
+                            }
+                        });
+            }
+            mAlertDialog.show();
             return true;
         }
 
         if (id == R.id.audio_list_browser_set_song) {
-            if (mSongsAdapter.getCount() <= groupPosition)
+            if (mSongsAdapter.getCount() <= position)
                 return false;
-            AudioUtil.setRingtone(mSongsAdapter.getItem(groupPosition).mMediaList.get(0), getActivity());
+            AudioUtil.setRingtone(mSongsAdapter.getItem(position).mMediaList.get(0), getActivity());
             return true;
         }
 
         if (useAllItems) {
-            if (mSongsAdapter.getCount() <= groupPosition)
+            if (mSongsAdapter.getCount() <= position)
                 return false;
             medias = new ArrayList<MediaWrapper>();
-            startPosition = mSongsAdapter.getListWithPosition(medias, groupPosition);
+            startPosition = mSongsAdapter.getListWithPosition(medias, position);
         } else {
             startPosition = 0;
             AudioBrowserListAdapter adapter = null;
@@ -488,11 +503,11 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                     adapter = mGenresAdapter;
                     break;
                 case MODE_PLAYLIST: //For file playlist, we browse tracks with mediabrowser, and add them in callbacks onMediaAdded and onBrowseEnd
-                    medias = mPlaylistAdapter.getMedias(groupPosition);
-                    if (medias.size() == 1 && mPlaylistAdapter.getMedias(groupPosition).get(0).getType() == MediaWrapper.TYPE_PLAYLIST) {
+                    medias = mPlaylistAdapter.getMedias(position);
+                    if (medias.size() == 1 && mPlaylistAdapter.getMedias(position).get(0).getType() == MediaWrapper.TYPE_PLAYLIST) {
                         if (mMediaBrowser == null)
                             mMediaBrowser = new MediaBrowser(VLCInstance.get(), this);
-                        mMediaBrowser.browse(mPlaylistAdapter.getMedias(groupPosition).get(0).getLocation());
+                        mMediaBrowser.browse(mPlaylistAdapter.getMedias(position).get(0).getLocation());
                         return true;
                     } else
                         adapter = mPlaylistAdapter;
@@ -500,9 +515,9 @@ public class AudioBrowserFragment extends MediaBrowserFragment implements SwipeR
                 default:
                     return false;
             }
-            if (groupPosition >= adapter.getCount())
+            if (position >= adapter.getCount())
                 return false;
-            medias = adapter.getMedias(groupPosition);
+            medias = adapter.getMedias(position);
         }
 
         if (append)
