@@ -66,8 +66,6 @@ import org.videolan.vlc.util.WeakHandler;
 import org.videolan.vlc.widget.ContextMenuRecyclerView;
 import org.videolan.vlc.widget.SwipeRefreshLayout;
 
-import java.io.File;
-import java.io.IOException;
 import java.util.ArrayList;
 
 
@@ -108,6 +106,7 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     public void onCreate(Bundle bundle){
         super.onCreate(bundle);
         mLibVLC = VLCInstance.get();
+        mMediaBrowser = new MediaBrowser(mLibVLC, this);
 
         if (bundle == null)
             bundle = getArguments();
@@ -258,8 +257,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     }
 
     protected void update(){
-        if (mMediaBrowser == null)
-            mMediaBrowser = new MediaBrowser(mLibVLC, this);
         if (mReadyToDisplay) {
             updateEmptyView();
             if (mAdapter.isEmpty()) {
@@ -272,7 +269,6 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 
     protected void updateDisplay() {
         if (!mAdapter.isEmpty()) {
-            mAdapter.sortList();
             if (mSavedPosition > 0) {
                 mLayoutManager.scrollToPositionWithOffset(mSavedPosition, 0);
                 mSavedPosition = 0;
@@ -336,18 +332,19 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
     public void onCreateContextMenu(ContextMenu menu, View v, ContextMenu.ContextMenuInfo menuInfo) {
         ContextMenuRecyclerView.RecyclerContextMenuInfo info = (ContextMenuRecyclerView
                 .RecyclerContextMenuInfo) menuInfo;
-        setContextMenu(getActivity().getMenuInflater(), menu, info.position);
+        if (info != null)
+            setContextMenu(getActivity().getMenuInflater(), menu, info.position);
     }
 
     protected void setContextMenu(MenuInflater inflater, Menu menu, int position) {
         MediaWrapper mw = (MediaWrapper) mAdapter.getItem(position);
+        boolean canWrite = Util.canWrite(mw.getLocation());
         if (mw.getType() == MediaWrapper.TYPE_AUDIO || mw.getType() == MediaWrapper.TYPE_VIDEO) {
-            boolean canWrite = Util.canWrite(mw.getLocation());
             inflater.inflate(R.menu.directory_view_file, menu);
             menu.findItem(R.id.directory_view_delete).setVisible(canWrite);
         } else if (mw.getType() == MediaWrapper.TYPE_DIR) {
             boolean isEmpty = mMediaLists.get(position) == null || mMediaLists.get(position).isEmpty();
-            if (/*canWrite || */!isEmpty) {
+            if (canWrite || !isEmpty) {
                 inflater.inflate(R.menu.directory_view_dir, menu);
 //                if (canWrite) {
 //                    boolean nomedia = new File(mw.getLocation() + "/.nomedia").exists();
@@ -358,8 +355,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
 //                    menu.findItem(R.id.directory_view_show_media).setVisible(false);
 //                }
                 menu.findItem(R.id.directory_view_play_folder).setVisible(!isEmpty);
+                menu.findItem(R.id.directory_view_delete).setVisible(canWrite);
             }
-
         }
     }
 
@@ -404,7 +401,8 @@ public abstract class BaseBrowserFragment extends MediaBrowserFragment implement
                 AudioServiceController.getInstance().append(mw);
                 return true;
             case R.id.directory_view_delete:
-                AlertDialog alertDialog = CommonDialogs.deleteMedia(getActivity(), mw.getLocation(),
+                AlertDialog alertDialog = CommonDialogs.deleteMedia(
+                        mw.getType(), getActivity(), mw.getLocation(),
                         new VLCRunnable() {
                             @Override
                             public void run(Object o) {
