@@ -20,20 +20,6 @@
 
 package org.videolan.vlc.util;
 
-import java.io.BufferedReader;
-import java.io.FileNotFoundException;
-import java.io.FileReader;
-import java.io.IOException;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashSet;
-import java.util.List;
-import java.util.StringTokenizer;
-
-import org.videolan.libvlc.LibVlcUtil;
-import org.videolan.vlc.R;
-import org.videolan.vlc.VLCApplication;
-
 import android.annotation.TargetApi;
 import android.content.Context;
 import android.net.ConnectivityManager;
@@ -46,8 +32,23 @@ import android.text.TextUtils;
 import android.view.InputDevice;
 import android.view.MotionEvent;
 
+import org.videolan.libvlc.LibVlcUtil;
+import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
+
+import java.io.BufferedReader;
+import java.io.FileNotFoundException;
+import java.io.FileReader;
+import java.io.IOException;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.HashSet;
+import java.util.List;
+import java.util.StringTokenizer;
+
 public class AndroidDevices {
     public final static String TAG = "VLC/Util/AndroidDevices";
+    public final static String EXTERNAL_PUBLIC_DIRECTORY = Environment.getExternalStorageDirectory().getPath();
 
     final static boolean hasNavBar;
     final static boolean hasTsp;
@@ -95,7 +96,7 @@ public class AndroidDevices {
     public static ArrayList<String> getStorageDirectories() {
         BufferedReader bufReader = null;
         ArrayList<String> list = new ArrayList<String>();
-        list.add(Environment.getExternalStorageDirectory().getPath());
+        list.add(EXTERNAL_PUBLIC_DIRECTORY);
 
         List<String> typeWL = Arrays.asList("vfat", "exfat", "sdcardfs", "fuse", "ntfs", "fat32", "ext3", "ext4", "esdfs");
         List<String> typeBL = Arrays.asList("tmpfs");
@@ -186,11 +187,4 @@ public class AndroidDevices {
         return networkEnabled;
 
     }
-
-    public static String getStorageTitle(String path){
-        if (TextUtils.equals(Environment.getExternalStorageDirectory().getPath(), path))
-            return VLCApplication.getAppContext().getString(R.string.internal_memory);
-        else
-            return Strings.getName(path);
-    }
 }
