@@ -43,7 +43,7 @@ public class BootupReceiver extends BroadcastReceiver {
     }
 
     private void scheduleRecommendationUpdate(Context context) {
-        AlarmManager alarmManager = (AlarmManager)context.getSystemService(
+        AlarmManager alarmManager = (AlarmManager) VLCApplication.getAppContext().getSystemService(
                 Context.ALARM_SERVICE);
         Intent recommendationIntent = new Intent(context,
                 RecommendationsService.class);
